@@ -67,11 +67,11 @@ resolver = "2" # avoid dependency conflicts on some platforms
 edition = "2018"
 
 [dependencies]
-sixtyfps = "0.1.2"
+sixtyfps = "0.1.3"
 ...
 
 [build-dependencies]
-sixtyfps-build = "0.1.2"
+sixtyfps-build = "0.1.3"
 ```
 
 In the `build.rs` file:
@@ -91,6 +91,14 @@ fn main() {
 }
 ```
 
+To quickly get started with this pattern, we have a [Template Repository](https://github.com/sixtyfpsui/sixtyfps-rust-template) that
+can be used with cargo-generate.
+
+```bash
+cargo install cargo-generate
+cargo generate --git https://github.com/sixtyfpsui/sixtyfps-rust-template
+```
+
 ## Generated components
 
 As of now, only the last component of a .60 source is generated. It is planned to generate all exported components.
@@ -150,6 +158,7 @@ The follow table summarizes the entire mapping:
 | --- | --- | --- |
 | `int` | `i32` | |
 | `float` | `f32` | |
+| `bool` | `bool` | |
 | `string` | [`SharedString`] | A reference-counted string type that can be easily converted to a str reference. |
 | `color` | [`Color`] | |
 | `brush` | [`Brush`] | |
@@ -716,7 +725,7 @@ macro_rules! include_modules {
 /// Helper type that helps checking that the generated code is generated for the right version
 #[doc(hidden)]
 #[allow(non_camel_case_types)]
-pub struct VersionCheck_0_1_2;
+pub struct VersionCheck_0_1_3;
 
 #[cfg(doctest)]
 mod compile_fail_tests;
